<!-- Entry template: -->
<!--
# Unreleased
## Added
## Changed
## Deprecated
## Removed
## Fixed
## Security
-->

Changelog for [Fallible](https://euandreh.xyz/fallible/en/).

# Unreleased
## Added

### `fallible/string.h`

Right now it still doesn't have "feature parity" with `string.h`, as in it doesn't have fallible counterparts for all functions in `string.h`.
The goal is for that to happen.

See
[#task-29c947fa-8780-4e18-0215-f72676bf3331](https://euandreh.xyz/fallible/TODOs.html#task-29c947fa-8780-4e18-0215-f72676bf3331)
for more information and discussion.

Done in
[`50e5cc2859f88dfe23eee94364a77b8a518cf6ca`](https://git.euandreh.xyz/fallible/commit/?id=50e5cc2859f88dfe23eee94364a77b8a518cf6ca).

### `die()` in `src/fallible.c`

From now one, `fallible_should_fail(3)` is completly pedantic about errors that occur within itself.

The reasoning behind this is that having errors inside fallible would compose terribly with fault injection in the application.

Done in
[`14009e9d7610aeec4f9a28940b17eef01e9603d6`](https://git.euandreh.xyz/fallible/commit/?id=14009e9d7610aeec4f9a28940b17eef01e9603d6).

### Return value of `fallible_should_fail(3)`

Now `fallible_should_fail(3)` returns `int` instead of `bool`.

The only reasoning behind this is to remove the `#include <stdbool.h>` in `src/fallible.h`, and make it shorter.

Done in
[`14009e9d7610aeec4f9a28940b17eef01e9603d6`](https://git.euandreh.xyz/fallible/commit/?id=14009e9d7610aeec4f9a28940b17eef01e9603d6)
and
[`d17bfdabc3a06ed1fe33d924dc778356fb5165fe`](https://git.euandreh.xyz/fallible/commit/?id=d17bfdabc3a06ed1fe33d924dc778356fb5165fe).

### `--valgrind-flags`
Add flag `--valgrind-flags` to `fallible-check`, to print the Valgrind flags used to check the programs.

This is useful for debugging leaks that `fallible-check` is detecting, as in:
```shell
$ valgrind `fallible-check --valgrind-flags` ./my-program
```

### `<fallible/string.h>`
New `<fallible/string.h>` header, currently containing only fallible counterparts of [`strdup.3`](fallible_strdup.3.html) and [`strndup.3`](fallible_strndup.3.html).
New fallible functions will be added on demand.

Its use is equivalent to `<fallible/alloc.h>`:

```c
#include <stdlib.h>
#include <string.h>

#ifdef ENABLE_FALLIBLE
#include <fallible/string.h>
#endif

int main() {
  char *s1 = strdup("a string that will leak");
  if (!s1) {
    perror("strdup");
    return EXIT_FAILURE;
  }

  char *s2 = strdup("another string");
  if (!s2) {
    // free(s1);
    perror("strdup");
    return EXIT_FAILURE;
  }

  free(s2);
	free(s1);
  return EXIT_SUCCESS;
}
```

Compile with `-DENABLE_FALLIBLE` to activate fault injection, and run with [`fallible-check.1`](fallible-check.1.html) to detect leaks:

```shell
$ c99 -DENABLE_FALLIBLE -o leaky-strdup leaky-strdup.c -lfallible
$ fallible-check ./leaky-strdup
(...suppressed output...)
# exit status is 1
```

## Changed
Set [`errno`](https://pubs.opengroup.org/onlinepubs/9699919799/basedefs/errno.h.html)
to `ENOMEM` before returning `NULL` from `<fallible/alloc.h>` functions.

# [0.3.0](https://git.euandreh.xyz/fallible/commit/?id=v0.3.0) - 2021-02-25
## Changed
Use macros to directly override function names.

Where before you had:

```c
#include <fallible/alloc.h>

void f() {
  void *v = MALLOC(10);
}
```

Now you have:
```c
#ifdef MY_FALLIBLE_FLAG
#include <fallible/alloc.h
#endif

void f() {
  void *v = malloc(10);
}
```

The `<fallible/alloc.h>` header now contains macros that directly override `malloc(size)`, instead of creating a `MALLOC(size)` alias.

The upside is that the code doesn't have to change, and that the Fallible library doesn't even have to be installed for the compilation to run, as long as the `MY_FALLIBLE_FLAG` isn't defined.

# [0.2.1](https://git.euandreh.xyz/fallible/commit/?id=v0.2.1) - 2021-02-22
## Changed
Use a plain `Makefile` instead of `./configure` + `Makefile.in`.

# [0.2.0](https://git.euandreh.xyz/fallible/commit/?id=v0.2.0) - 2021-02-21
## Added
Produce binaries with debug symbols (`-g` on `$(CFLAGS)`).

## Changed
Move `<fallible_alloc.h>` to `<fallible/alloc.h>`.

Future headers will follow the same patter and will be put in `<fallible/header_here.h>`.

## Removed
`tests/integration/unsafe.c` was deleted.
It assumed what the behaviour of `strcpy(NULL, "")` would be, and assert it would fail.
However, since the behaviour is *undefined*, this premise doesn't necessarily hold.
The test was deleted.

# [0.1.0](https://git.euandreh.xyz/fallible/commit/?id=v0.1.0) - 2021-02-16
## Added
Initial public release.
