#!/bin/sh
set -eu

LANGS=
while getopts 'l:L:' flag; do
	case "$flag" in
		l)
			LANGS="$OPTARG"
			;;
		L)
			CONTRIBLANGS="$OPTARG"
			;;
		*)
			exit 2
			;;
	esac
done
shift $((OPTIND - 1))

assert_arg() {
	if [ -z "$1" ]; then
		echo "Missing $2" >&2
		exit 2
	fi
}

assert_arg "${LANGS:-}" '-l LANGS'

for from_f in "$@"; do
	for lang in $LANGS ${CONTRIBLANGS:-}; do
		to_f="$(echo "$from_f" | sed "s/\.en\./.$lang./")"
		printf 'Generating %s...\n' "$to_f"
		pofile="po/LC_MESSAGES/$from_f/$lang.po"
		mkdir -p "$(dirname "$pofile")"

		case "$from_f" in
			*.en.[1-9].in)
				po4a-updatepo -f man -m "$from_f" -p "$pofile"
				po4a-translate -f man -m "$from_f" -p "$pofile" -l "$to_f" -k 0 -v >&2
				;;
			*.en.md)
				touch "$pofile"
				md2po "$from_f" --include-codeblocks --quiet --save --po-filepath "$pofile"
				po2md "$from_f" --pofiles "$pofile" --quiet --save "$to_f"
				;;
			*)
				echo "Unsupported file format: $from_f" >&2
				exit 2
				;;
		esac
	done
done

end="\033[0m"
yellowb="\033[1;33m"
for lang in $LANGS; do
	# shellcheck disable=2044
	for pofile in $(find po/ -type f -name "$lang.po"); do
		if LANG=POSIX msgfmt --statistics "$pofile" 2>&1 | grep untranslated; then
			printf "\n\t${yellowb}WARNING${end}!\n	Missing translations for %s\n\n" "$pofile" >&2
		fi
	done
done
