#ifndef _POSIX_C_SOURCE
#define _POSIX_C_SOURCE 200809L
#endif

#include "fallible.h"
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>
#include <stdbool.h>


#ifdef TEST
#include "unit-test.h"
#endif

static const char *const DEFAULT_DB_NAME = "fallible-default";

static int digits(int n) {
	if (n == 0) {
		return 1;
	}

	int count = 0;
	while (n) {
		count++;
		n /= 10;
	}
	return count;
}


#ifdef TEST
static void digits_test() {
	testing("Counting of digits");
	asserte(digits(0) == 1);
	asserte(digits(1) == 1);
	asserte(digits(9) == 1);
	asserte(digits(10) == 2);
	asserte(digits(11) == 2);
	asserte(digits(99) == 2);
	asserte(digits(100) == 3);
	asserte(digits(999) == 3);
	asserte(digits(1000) == 4);
	asserte(digits(-1) == 1);
	asserte(digits(-9) == 1);
	asserte(digits(-10) == 2);
	asserte(digits(-999) == 3);
	asserte(digits(-1234) == 4);
	test_ok();
}
#endif

int fallible_should_fail(const char *const filename, int lineno) {
	int original_errno = errno;

	FILE *f = NULL;

	const char *die_msg = NULL;
	char *current = NULL;
	char *line = NULL;
	bool should_fail = true;

	const char *db_name = getenv("FALLIBLE_FILE");
	if (!db_name) {
		db_name = DEFAULT_DB_NAME;
	}

	if (!(f = fopen(db_name, "a+"))) {
		die_msg = "fallible_should_fail() - fopen($FALLIBLE_FILE)";
		goto cleanup;
	}

	size_t size =
		strlen(filename) +
		strlen(":")      +
		digits(lineno)   +
		strlen("\n")     +
		sizeof(char);
	if (!(current = malloc(size))) {
		die_msg = "fallible_shoul_fail() - malloc()";
		goto cleanup;
	}

	if (sprintf(current, "%s:%d\n", filename, lineno) < 0) {
		die_msg = "fallible_should_fail() - sprintf()";
		goto cleanup;
	}

	size_t len = 0;
	errno = 0;
	while (getline(&line, &len, f) != -1) {
		if (errno != 0) {
			die_msg = "fallible_should_fail() - getline()";
			goto cleanup;
		}
		if (!strcmp(line, current)) {
			should_fail = false;
			goto cleanup;
		}
		errno = 0;
	}

	if (fprintf(f, "%s", current) < 0) {
		die_msg = "fallible_should_fail() - fprintf()";
		goto cleanup;
	}

cleanup:
	free(current);
	free(line);

	int errno_before_fclose = errno;
	if (f && (fclose(f) == EOF)) {
		if (die_msg) {
			errno = errno_before_fclose;
		} else {
			die_msg = "fallible_should_fail() - fclose()";
		}
	}

	if (die_msg) {
		perror("fallible_should_fail()");
		fprintf(stderr, "%s\n", die_msg);
		should_fail = true;
	}

	errno = original_errno;
	return should_fail;
}

#ifdef TEST
int main(void) {
	digits_test();
	return EXIT_SUCCESS;
}
#endif
